/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

/**
 *  This interface contains the methods which must be implemented
 *  by ant developers. The main method to be implemented is
 *  <CODE>run()</CODE>, which is invoked by a nest when an ant
 *  is received. Method <CODE>run()</CODE> contains the ant
 *  algorithm.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Ant
{

  /**
   *  This method is called on ants at the initialization time.
   *  The view delivered to ants is not fully functional; for
   *  example, ants cannot move to other nests or create new
   *  ants during the execution of <CODE>init()</CODE>.
   *  FIXME Implement the control in LocalAntView.
   */
  public void init(AntView view);


  /**
   *  This method encapsulate the computation performed by ants.
   *  It is invoked once by a nest when the ant is received by 
   *  another nest, or when the ant is generated locally. The 
   *  <CODE>run()</CODE> method must be executed in a controlled
   *  environment, meaning that the ant cannot be enabled to
   *  access nest resources besides of the methods provided
   *  by the <CODE>AntView</CODE> interface.
   *
   *  @param view reference to the <CODE>AntView</CODE> object which
   *    is the communication interface between ants and nests.
   */
  public void run(AntView view);

  
  /**
   *  Returns the identifier of the "species" of this ant.
   *  Different ant species may have access to different
   *  pheromone information in nests.
   */
  public String getSpecies();
  
  
} // END Ant


