/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import java.io.*;

/**
 *  The <CODE>Resource</CODE> interface describes resources that may be
 *  stored in a nests. Each resource is uniquely identified by
 *  its string name.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Resource
{
  
  /**
   *  Returns the key identifier of the object.
   */
  public Object getKey();
  
  /**
   *  Returns the string identifier of the object.
   */
  public String getName();
  
  
  /**
   *  Returns the value associated to the specified attribute
   *  name, or null if there is no attribute with that name.
   *
   *  @param name the name of the attribute
   */
  public String getAttribute(String name);

  
  /**
   *  Return an input stream to download the contents of the
   *  resource. Depending on the implementation, the contents
   *  may be read from the local storage, if the resource has
   *  been copied locally; or downloaded remotely, otherwise.
   *
   *  @return an input stream to read the contents of a resource;
   */
  public InputStream getInputStream()
    throws IOException;

  
  /**
   *  Return the lenght of the content of the resource, if
   *  available; otherwise, it returns -1.
   */
  public long getContentLength();


  /**
   *  Return the space required to store the resource object.
   */
  public long size();

  
} // END Resource

