/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.antsim;

import anthill.*;
import anthill.util.*;

/**
 *  The <CODE>Experiment</CODE> interface represents the execution
 *  of a set of <CODE>Scenario</CODE>s. When executed, an experiment
 *  returns a collection of <CODE>Stats</CODE> objects containing
 *  statistics about the behavior of the current ant algorithm.
 *  <p>
 *  Different <CODE>Experiment</CODE> implementations may provide
 *  distinct functionalities to ant developers. For example, a 
 *  basic implementation could simply repeat the execution of the
 *  same scenario for a certain number of times, while others
 *  could collect statistics for different scenarios, or show
 *  the behavior of an algorithm over time.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Experiment
extends Clearable
{
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Perform the evaluation of the current ant algorithm. Returns an
   *  array of <CODE>Stats</CODE> objects containing the statistics 
   *  collected during the simulation. 
   */
  public Stats[] evaluate();
  
} // END Experiment

