/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.antsim;

import anthill.*;
import anthill.util.*;

/**
 *  Interface <CODE>ResourceSet</CODE> is used in scenarios in order to
 *  obtain a set of resources to be inserted in the simulated peer network 
 *  and a set of requests to be performed. 
 *  
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface ResourceSet
extends Clearable
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods for obtaining resources
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Return the number of resources generated and stored in
   *  this <CODE>ResourceSet</CODE>.
   */
  public int size();

  /**
   *  Return an array containing the resources generated and 
   *  stored in this <CODE>ResourceSet</CODE>.
   */
  public Resource[] getResources();
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods for obtaining requests
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Generate a random request. Depending on the implementation of 
   *  this class, the request could be the identifier of the one of 
   *  the resources contained in this <CODE>ResourceSet</CODE>,
   *  or a more specific request (for example, a free query based on
   *  keywords, or an insert request).
   */
  public Object getRequest();
  
} // END ResourceSet

