/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.antsim;

import anthill.*;
import anthill.util.*;

/**
 *  Interface <CODE>Scenario</CODE> represents a run of the simulation
 *  of a particular ant algorithm. Generally, a scenario is composed
 *  by a simulated peer-to-peer network (represented by interface
 *  <CODE>Peernet</CODE>), plus a set of resources to be
 *  inserted in the network and a set of requests to be performed
 *  (represented by interface <CODE>ResourceSet</CODE>). The scenario
 *  is simulated by executing the ant algorithm over the simulated
 *  peer-to-peer network by performing the requests. Statistics 
 *  about the behavior of the system during the run of a scenario may
 *  be obtained by setting a <CODE>Stats</CODE> object through
 *  method <CODE>setStats()</CODE>.
 *  
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Scenario
extends Clearable
{
  
  /**
   *  Set the statistics object which will be used throughout
   *  the scenario evaluation.
   *  
   *  @param stats the object used to collect statistics
   */
  public void setStats(Stats stats);
  
  /**
   *  Perform the evaluation of this scenario object by simulating it.
   */
  public void evaluate();
  

} // END Scenario

