/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.antsim.impl;

import anthill.*;
import java.util.*;
import java.io.*;

/**
 *  A <CODE>RandomResource</CODE> is characterized only by its name, which is 
 *  a string obtained from a long value generated randomly.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class RandomResource
implements Resource
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static field
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Random generator */
  private static Random random = new Random();
  
  static int counter = 0;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** String name of the resource, randomly generated */
  private String name;
  
  private long value;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Construct a resource with a random name
   */
  public RandomResource()
  {
    value = counter++;
    //value = random.nextLong();
    name = Long.toString(value);
  }
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Returns the key identifier of the object.
   */
  public Object getKey()
  {
    return name;
  }

  /**
   *  Returns the string identifier of the object.
   */
  public String getName()
  {
    return name;
  }
  
  
  /**
   *  Returns the value associated to the specified attribute
   *  name, or <CODE>null</CODE> if there is no attribute with that name.
   *  <p>
   *  Implementation note: in this simple implementation, this
   *  feature is not present; exception 
   *  <CODE>UnsupportedOperationException</CODE> is raised.
   *
   *  @param name the name of the attribute
   */
  public String getAttribute(String name)
  {
    throw new UnsupportedOperationException();
  }

  
  /**
   *  Return an input stream to download the contents of the
   *  resource. Depending on the implementation, the contents
   *  may be read from the local storage, if the resource has
   *  been copied locally; or downloaded remotely, otherwise.
   *  <p>
   *  Implementation note: in this simple implementation, this
   *  feature is not present; exception 
   *  <CODE>UnsupportedOperationException</CODE> is raised.
   *
   *  @return an input stream to read the contents of a resource;
   */
  public InputStream getInputStream()
  {
    throw new UnsupportedOperationException();
  }

  
  /**
   *  Return the lenght of the content of the resource, if
   *  available; otherwise, it returns -1.
   *  <p>
   *  Implementation note: in this simple implementation, this
   *  feature is not present; exception 
   *  <CODE>UnsupportedOperationException</CODE> is raised.
   */
  public long getContentLength()
  {
    return 1;
  }

  public long size()
  {
    return 1;
  }

  /**
   *  Return a string representing this resource
   */
  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("[");
    buf.append(this.getClass().getName());
    buf.append(": ");
    buf.append(name);
    buf.append("]");
    return buf.toString();
  }
  
  /**
   *  Indicates whether some other object is "equal to" this one
   */
  public boolean equals(Object obj)
  {
    try {
      RandomResource resource = (RandomResource) obj;
      return resource.value == this.value;
    } catch (Exception e) {
      return false;
    }
  }
  
} // END RandomResource

