/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.antsim.impl;

import anthill.*;
import anthill.nest.*;

/**
 *   
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class Rid
implements RequestId
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static section 
  ////////////////////////////////////////////////////////////////////////////////////////////

  private static int counter = 0;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /** Identifier of the nest that generated this request id */
  private Nest nest;
  
  /** Progressive counter */
  private int val;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  public Rid(Nest nest)
  {
    this.nest = nest;
    val = ++counter;
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Public Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  public Nest getNest()
  {
    return nest;
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Object Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Check whether this <CODE>Rid</CODE> is equal to the specified object.
   */
  public boolean equals(Object obj)
  {
    if (obj != null && obj instanceof Rid) {
      Rid rid = (Rid) obj;
      return (rid.nest.equals(this.nest)) && (rid.val == this.val);
    } else {
      return false;
    }
  }

  /**
   *  Returns a hash code value for the object.
   */
  public int hashCode()
  {
    return nest.hashCode() + val;
  }
  
  /**
   *  Returns a string representation of the object.
   */
  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("[Rid: nest ");
    buf.append(nest);
    buf.append(", ");
    buf.append(val);
    buf.append("]");
    return buf.toString();
  }
  
}

