/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.factory;

/**
 *  Container for classes implementing an interface,
 *  including its arguments. This is used for storing
 *  in the Factory's HashMap.
 *
 *  @author Hein Meling
 *  @version $Revision$
 */
class ClassData
{

  /////////////////////////////////////////////////////////////////////////////
  // Fields
  /////////////////////////////////////////////////////////////////////////////

  /** */
  String clazz;

  /** The names of the arguments */
  String[] names;

  /** The types of the arguments */
  Class[] types;

  /** The arguments to be passed */
  Object[] args;

  /** The version of this parameter configuration */
  int version;

  
  /////////////////////////////////////////////////////////////////////////////
  // Constructor
  /////////////////////////////////////////////////////////////////////////////

  ClassData(String clazz, String[] names, Class[] types, Object[] args) 
  {
    this.version = 0;
    this.clazz = clazz;
    this.names = names;
    this.types = types;
    this.args  = args;
  }

  /////////////////////////////////////////////////////////////////////////////
  // Methods
  /////////////////////////////////////////////////////////////////////////////

  void update(String clazz, String names[], Class[] types, Object[] args) 
  {
    version++;
    this.clazz = clazz;
    this.names = names;
    this.types = types;
    this.args = args;
  }

} // END ClassData
