/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie;

import anthill.*;

/**
 *  Factory interface for creating ants with genetic codes. This interface 
 *  is used by nests to create ant which will be used to perform searches
 *  in the Anthill network.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface GeneticAntFactory
{
  
  /**
   *  Factory method for creating ants. The genetic code of the
   *  ant must be specified, together with the request to be performed.
   *  The genetic code is interpreted by the particular ant species;
   *  if the genetic code is not compatible with the ant species, an
   *  <CODE>IllegalArgumentException</CODE> is thrown.
   * 
   *  @param code 
   *    the genetic code to be used for the generated ant
   *  @param request 
   *    the request to be performed
   *  @throws IllegalArgumentException 
   *    if the genetic code is not compatible (e.g., it is longer or 
   *  shorter than required) with  the specified ant species.
   */
  public Ant[] getAnts(GeneticCode code, Object request);

  
} // END AntFactory


