/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie;

import anthill.*;
import gajit.*;

/**
 *  The GeneticFramework class is used to manage the genetic
 *  evolution.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface GeneticFramework
{
  
  /**
   *  Try to evolve a population of genetic codes, using the
   *  configuration parameters contained in this instance
   *
   *  @param out  print stream used to log information about the
   *    evolution; if print stream is null, no log file is generated.
   */
  public void evolve();
  
  /**
   *  Return the population of evolved genetic codes. 
   */
  public Population getPopulation();

  
  /**
   *  Return the genetic code with the best fitness.
   */
  public GeneticCode getFittest();
  

} // END GeneticEnvironment

