/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie;

import anthill.*;
import anthill.nest.*;
import anthill.util.*;

/**
 *  The <CODE>GeneticNest</CODE> interface extends <CODE>Nest</CODE> 
 *  with methods for managing genetic codes to be used in the creation 
 *  of new ants during the evaluation of the fitness of a genetic ant 
 *  algorithm.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface GeneticNest
extends Nest
{
  
  /**
   *  Add a new genetic code to the set of genetic codes known to this 
   *  nest. When creating a new ant, this nest may choose from one of the
   *  available genetic codes. If an implementation of <CODE>GeneticNest</CODE> 
   *  does not enable the use of more than one genetic code, duplicated
   *  invocations of <CODE>addGeneticCode()</CODE> must throw an 
   *  <CODE>IllegalStateException</CODE>.
   * 
   *  @param code the genetic code to be added
   *  @throws IllegalStateException if no other genetic code can be added to
   *    this nest
   */
  public void addGeneticCode(GeneticCode code);
  
  
} // END GeneticNest
