/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie.impl;

import anthill.*;
import anthill.genie.*;
import anthill.antsim.*;

/**
 *  Evaluate the fitness of a particular ant algorithm based on
 *  the statistics collected during its simulation. 
 *  <p>
 *  This implementation returns the ratio between the number
 *  of resources found and the number of resources searched.
 *  <p>
 *  Used keys: FoundResources, RequestedResources
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class FindingFitness
implements Fitness
{
  
  /**
   *  Evaluate the fitness of a particular ant algorithm based on
   *  the statistics collected during its simulation. 
   *  <p>
   *  This implementation returns the ratio between the number
   *  of resources found and the number of resources searched.
   */
  public float compute(Stats stats)
  {
    float found = stats.get("FoundResources");
    float requested = stats.get("RequestedResources");
    return found/requested;
  }

}
