/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie.impl;

import anthill.*;
import anthill.nest.*;
import anthill.factory.*;
import anthill.antsim.impl.*;
import anthill.genie.*;
import anthill.util.*;
import java.util.*;


/**
 *  This is the scenario
 *  
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class GeneticScenarioImpl
extends ScenarioImpl
implements GeneticScenario
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** GeneticCode to be evaluated */
  private GeneticCode code;

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Instantiates a new ScenarioImpl.
   *
   *  @param pnf Peernet factory to be used to generate networks 
   */
  public GeneticScenarioImpl(Factory factory, int nrequests, int initRounds, int rounds, int finalRounds)
  {
    super(factory, nrequests, initRounds, rounds, finalRounds);
    code = null;
  }
  
  /**
   *  Restores the object to its initial state. The network is re-initialized
   *  as an empty network.
   */
  public void clear()
  {
    super.clear();
    code = null;
  }
   
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Scenario
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Set the genetic code to be evaluated. In this basic implementation,
   *  only one genetic code can be present in a scenario at a time.
   *  If this method is called more than once, exception 
   *  <CODE>IllegalStateException</CODE>
   *  is thrown.
   *  
   *  @throws IllegalStateException if this method is added more than once. 
   */
  public void addGeneticCode(GeneticCode code)
  {
    if (this.code != null)
      throw new IllegalStateException("Class " + this.getClass() + 
        "can evaluate only one genetic code");
    this.code = code;
    Nest[] nests = net.getNests();
    for (int i=0; i < nests.length; i++) {
      ((GeneticNest) nests[i]).addGeneticCode(code);
    }
  }
  

} // END GeneticScenarioImpl

