/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nest;

import anthill.*;

/**
 *  This class contains information about an ant,including the 
 *  identifier of the nest which has sent it to this host, the 
 *  identifier of the ant, the remaining time-to-live and a 
 *  reference to the ant itself.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class AntDescriptor
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** NestId of the sender of this ant */
  private NestId sender;
  
  /** Ant associated to this data structure */
  private Ant ant;
  
  /** Time-to-live */
  private int ttl;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Instantiates an ant descriptor and copies the initialization
   *  parameters in it.
   */
  public AntDescriptor(NestId sender, Ant ant, int ttl)
  {
    this.sender = sender;
    this.ant = ant;
    this.ttl = ttl;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Return a reference to the ant associated with this ant descriptor.
   */
  public Ant getAnt()
  {
    return ant;
  }
  
  /**
   *  Return the identifier of the last nest visited by the ant associated
   *  with this ant descriptor.
   */
  public NestId getLastVisited()
  {
    return sender;
  }

  /**
   *  Return the remaining time-to-live of this ant.
   */
  public int getTTL()
  {
    return ttl;
  }

} // END AntDescriptor


