/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nest;

import java.rmi.*;

/**
 *  This interface must be implemented by nests in order to receive
 *  ants from other nests. The main method of the interface is
 *  <CODE>deliver()</CODE>. The interface is designed as a remote
 *  interface (i.e., it extends <CODE>Remote</CODE> and method
 *  <CODE>deliver()</CODE> delivers <CODE>RemoteException</CODE>, 
 *  in order to enable the development of implementation based on 
 *  RMI. Note, however, that implementations of this class are not 
 *  required to be based on RMI. 
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface AntListener
extends Remote
{

  /**
   *  This method is invoked to notify the ant listener that an ant
   *  coming from the given nest has been received
   *
   *  @param sender the identifier of the nest from which this ant 
   *    has been received
   *  @param desc the ant descriptor of the received ant
   *  @exception RemoteException added to the throw clause to respect
   *    the conventions for remote interfaces.
   */
  public void deliver(AntDescriptor desc)
    throws RemoteException;

  
} // END AntListener
