/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nest;

import anthill.*;
import anthill.util.*;

import java.io.*;

/**
 *  The <CODE>Gate</CODE> interface contains the set of methods
 *  used by a nest to communicate with other nests.
 *  <p>
 *  <CODE>Gate</CODE> is one of the components of a nest; the
 *  other are  <CODE>Manager</CODE>), <CODE>RequestSet</CODE>, 
 *  <CODE>Storage</CODE> and <CODE>Trail</CODE>.
 *  <p>
 *  <CODE>Gate</CODE> methods are invoked by <CODE>AntView</CODE>
 *  objects to implement methods <CODE>move()</CODE>,
 *  <CODE>addNeighbour</CODE>, <CODE>getNeighbours</CODE>
 *  and <CODE>removeNeighbour()</CODE>. The exact behavior of
 *  these methods depends on the implementation of <CODE>Gate</CODE>.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Gate
extends Clearable
{
  
  /**
   *  Returns the identifier of the nest containing this gate.
   */
  public NestId getId();

  
  /**
   *  Sets the ant listener, i.e. the object that will
   *  accept the ants coming from other nests.
   *
   *  @param listener the listener object that will
   *    accepts the ants coming from other nests
   */
  public void setAntListener(AntListener listener);
  
  
  /**
   *  Sends an ant to the specified nest. Both the nest
   *  identifier and the ant must be serializable or
   *  externalizable.
   *
   * @exception ClassCastException
   *   raised if the nest identifier does not belong to the
   *   expected class
   * @exception IOException
   *   raised if problems have occurred during serialization
   *   and sending
   */
  public void send(NestId dest, Ant ant, int ttl)
    throws IOException, ClassCastException;
  
} // END Gate
