/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nest;

import anthill.*;

import java.io.*;

/**
 *  Listener interface which must be implemented by objects
 *  that want to be notified about the results of a request.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface ResponseListener
{
  
  /**
   *  Upcall method used to notify this listener that the request 
   *  associated to it has returned the specified set of resources.
   * 
   *  @param resources the resources found.
   */
  public void returnResources(RequestId rid, Resource[] resources);
  
  
  /**
   *  Upcall method used to notify this listener that the request 
   *  associated to it has finished to return resources.
   */
  public void complete();
  
} // END ResponseListener

