/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nest;

import anthill.*;
import anthill.util.*;

/**
 *  This interface represents a container for associations
 *  (ant identifier, previous nest identifier) stored in 
 *  nests. These associations may be used by ants to return 
 *  to the requestor nest which has originated them, without
 *  having to carry this information with them.
 *  <p>
 *  The interface contains two methods, one to add an
 *  association (ant identifier, previous nest), the
 *  other to obtain, given the ant identifier, the 
 *  identifier of the previous nest.
 *  <p>
 *  <CODE>Trail</CODE> is one of the components of a nest; the
 *  other are <CODE>Manager</CODE>), <CODE>RequestSet</CODE>, 
 *  <CODE>Storage</CODE> and <CODE>Gate</CODE>.
 *  <p>
 *  <CODE>Trail</CODE> methods are invoked by <CODE>AntView</CODE>
 *  objects to implement methods <CODE>storePreviousNest()</CODE>
 *  and <CODE>getPreviousNest()</CODE>. The exact behavior of
 *  these methods depends on the implementation of <CODE>Trail</CODE>.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Trail
extends Clearable
{
  
  
  /**
   *  Add a pair (ant identifier, previous nest identifier) to 
   *  <CODE>Trail</CODE> object. Returns true if the ant identifier 
   *  is not already  included in this <I>Trail</I> object; return 
   *  false otherwise.  The "false" notification can be used to 
   *  detect duplicated visits to a nest.
   */
  public boolean add(AntId id, NestId source);
  
  /**
   *  Lookup the <I>Trail</I> object in order to obtain the 
   *  identifier of the nest from which the specified 
   *  ant arrived. 
   *  
   *  @param id the identifier of the ant 
   *  @param remove true if the association (ant id, nest id)
   *    should be removed after retrieval
   */
  public NestId lookup(AntId id, boolean remove);

  
} // END Trail

