/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import anthill.nest.*;

/**
 *  Class <CODE>LocalAid</CODE> is the implementation of <CODE>AntId</CODE> 
 *  to be used during off-line simulation. Unique identifiers are generated
 *  using a counter. 
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class LocalAid
implements AntId
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static section
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Counter used to generate unique identifiers */
  private static long counter = 0;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Identifier */
  private long id;
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Builds a new local identifier by incrementing the counter.
   */
  public LocalAid()
  {
    id = ++counter;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Object
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Check whether this <CODE>LocalAid</CODE> is equal to the specified object.
   */
  public boolean equals(Object obj)
  {
    if (obj != null && obj instanceof LocalAid) {
      LocalAid id = (LocalAid) obj;
      return (this.id == id.id);
    } else {
      return false;
    }
  }

  /**
   *  Returns a hash code value for the object.
   */
  public int hashCode()
  {
    return (int) id;
  }
  
  /**
   *  Returns a string representation of the object.
   */
  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("[");
    buf.append(this.getClass().getName());
    buf.append(": ");
    buf.append(id);
    buf.append("]");
    return buf.toString();
  }

  public long getId()
  {
    return id;
  }
  
} // END LocalAid

