/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import anthill.nest.*;
import anthill.factory.*;
import anthill.util.*;

import java.util.*;

/**
 *  Class <CODE>LocalManager</CODE> is the implementation of <CODE>Manager</CODE>
 *  to be used during off-line simulations. No thread is used in this implementation;
 *  instead, the execution of the algorithm of a single ant may be forced by invoking
 *  method <CODE>execute()</CODE>. This method is used by <CODE>Scenario</CODE>
 *  implementations in order to force progress of the ant algorithm over the 
 *  simulated network.
 *  
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class LocalManager
implements Manager
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Queue containing the ants to be computed */
  LinkedList queue;
  LinkedList empty;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  
   */
  public LocalManager()
  {
    queue = new LinkedList();
    empty = new LinkedList();
    //queue = new Queue();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Manager
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Adds an ant to the queue of ants to be executed
   *
   *  @param view the ant to be added is encapsulated
   *    in a <CODE>AntView</CODE>
   */
  public void add(AntView view)
  {
    queue.add(view);
  }
  
  
  /**
   *  Executes an ant stored in this <CODE>LocalManager</CODE>. 
   */
  public void execute()
  {
    LinkedList toexecute = queue;
    queue = empty;
    while (toexecute.size() > 0) {
      AntView view = (AntView) toexecute.removeFirst();
      if (view != null) {
        Ant ant = view.getAnt();
        ant.run(view);
      }
    }
    empty = toexecute;
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Clearable
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Restores the object to its initial state.
   */
  public void clear()
  {
    queue.clear();
  }
  
} // END Manager
