/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import anthill.nest.*;

/**
 *  Class <CODE>LocalNid</CODE> is the implementation of NestId for the
 *  to be used during off-line simulation. Unique identifiers are generated
 *  using a counter. 
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class LocalNid
implements NestId
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static section
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Counter used to generate unique identifiers */
  private static long counter = 0;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Identifier */
  private long id;
  
  /** Gate object associated with this id */
  private LocalGate gate;
  
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Builds a new local identifier
   */
  public LocalNid(LocalGate gate)
  {
    id = ++counter;
    this.gate = gate;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Returns the <CODE>LocalGate</CODE> object associated to this identifier. This method is 
   *  invoked by a <CODE>LocalGate</CODE> object when it needs to deliver an ant to the
   *  nest identified by this <CODE>NestId</CODE>. By obtaining the reference of the
   *  <CODE>LocalGate</CODE> associated to the identifier, it can queue the ant.
   */
  LocalGate getGate()
  {
    return gate;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Object
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Check whether this <CODE>LocalNid</CODE> is equal to the specified object.
   */
  public boolean equals(Object obj)
  {
    if (obj != null && obj instanceof LocalNid) {
      LocalNid id = (LocalNid) obj;
      return (this.id == id.id);
    } else {
      return false;
    }
  }

  /**
   *  Returns a hash code value for the object.
   */
  public int hashCode()
  {
    return (int) id;
  }
  
  /**
   *  Returns a string representation of the object.
   */
  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("[");
//     buf.append(this.getClass().getName());
//     buf.append(": ");
    buf.append(id);
    buf.append("]");
    return buf.toString();
  }
  
} // END LocalNid

