/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.storage;

import anthill.*;
import anthill.util.*;

/**
 *  Base class for the exceptions thrown by Capacity.
 *
 *  @author     Alberto Montresor
 *  @since      Capacity 0.1
 */
public class CapacityException extends Exception
{

  /** Capacity */
  private long capacity;
  
  /** Requested capacity */
  private long requestedCapacity;

  /** Remaining capacity */
  private long remainingCapacity;
  
  /**
   *  Constructs a <code> CapacityExeception</code> with no detail message.
   */
  public CapacityException()
  {
    super("Capacity exception");
  }

  /**
   *  Constructs a <code> CapacityExeception</code> with the specified message.
   *  @param capacity initial capacity
   *  @param remainingCapacity remaining capacity
   *  @param requestedCapacity requested capacity
   */
  public CapacityException(long capacity, long reaminingCapacity, 
    long requestedCapacity)
  {
    this();
    this.capacity = capacity;
    this.remainingCapacity = remainingCapacity;
    this.requestedCapacity = requestedCapacity;
  }

  /**
   *  Returns the initial capacity of the storage which raised 
   *  this exception.
   */
  public long getCapacity()
  {
    return capacity;
  }
  
  /**
   *  Returns the remaining capacity of the storage which raised 
   *  this exception.
   */
  public long getRemainingCapacity()
  {
    return remainingCapacity;
  }

  /**
   *  Returns the requested capacity for the resource whose
   *  insertion generated this exception.
   */
  public long getRequestedCapacity()
  {
    return requestedCapacity;
  }

} // END CapacityException
