/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.storage;

import anthill.*;
import anthill.factory.*;

import java.util.*;

/**
 *  Implementation of an LRU based query storage.  This is a wrapper class
 *  for storing resources based on using a query to access the resources.
 *  It inherits all methods from the <CODE>LRUKeyStorage</CODE>,
 *  but adds a method to retrieve resources based on a query.
 *
 *  @author Hein Meling
 *  @version $Revision$
 */
public interface QueryStorage
extends GenericStorage
{

  /**
   *  Return the resource associated with the specified query.
   *
   *  @param query  whose associated resource to retreive.
   *  @return resources found in the storage with which the
   *    specified query matched.
   */
  public Resource[] getResources(Object query);

} // END QueryStorage

