/*
 * Copyright (c) 1998-2000 The Anthill Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.storage;

import java.io.*;

/**
 *  StorageNotFoundException is 
 *  FIXME ALB Should be a checked exception?
 *
 *  @author  Alberto Montresor
 *  @version $Revision$
 */
public class StorageNotFoundException 
extends RuntimeException 
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Target exception */
  private Throwable target;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Private constructor to avoid defualt instantiation
   */
  private StorageNotFoundException() 
  {
  }
  
  /**
   * Constructs a <code>StorageNotFoundException</code> with a target exception.
   */
  public StorageNotFoundException(Throwable target) 
  {
    this.target = target;
  }
  
  /**
   * Constructs a <code>StorageNotFoundException</code> with a target exception
   * and a detail message.
   */
  public StorageNotFoundException(Throwable target, String s) 
  {
    super(s);
    this.target = target;
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Get the thrown target exception.
   */
  public Throwable getTargetException() 
  {
    return target;
  }
  
  /**
   * Prints the stack trace of the thrown target exception.
   */
  public void printStackTrace() 
  {
    printStackTrace(System.err);
  }
  
  /**
   * Prints the stack trace of the thrown target exception to the specified
   * print stream.
   */
  public void printStackTrace(PrintStream ps) 
  {
    ps.print("anthill.factory.StorageNotFoundException: ");
    target.printStackTrace(ps);
  }
  
  /**
   * Prints the stack trace of the thrown target exception to the
   * specified print writer.
   */
  public void printStackTrace(PrintWriter pw) 
  {
    pw.print("anthill.factory.StorageNotFoundException: ");
    target.printStackTrace(pw);
  }
  
} // END StorageNotFoundException
