/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.storage.impl;

import anthill.*;
import anthill.storage.*;
import anthill.factory.*;

import java.util.*;

/**
 *  This class is used to verify if an object is 
 *  
 *  @author Alberto Montresor
 *  @author Hein Meling
 *  @version $Revision$
 */
public class ANDQueryController 
implements QueryController
{
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Factory used to instantiate objects */
  private Factory factory;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Constructor for the query controller
   *
   *  @param factory factory object used to instantiate objects and obtaining
   *    configuration values
   */
  public ANDQueryController(Factory factory)
  {
    // FIXME ALB Why factory?
    this.factory = factory;
    //    clear();
  }

  /**
   *  Returns the result of matching the specified query with the
   *  given resource.
   *
   *  @param resource  to match the query against.
   *  @param query     query object match the specified resource against.
   *  @return true if the specified resource match the specified query.
   */
  public boolean satisfies(Resource resource, Object query)
  {
    String querystring;
    try {
      querystring = (String) query;
    } catch (ClassCastException e) {
      return false;
    }
    StringTokenizer tokenizer = new StringTokenizer(querystring);
    String name = resource.getName();
    while (tokenizer.hasMoreTokens()) {
      if (name.indexOf(tokenizer.nextToken()) < 0)
        return false;
    }
    // System.out.println("Query: " + query);
    // System.out.println("Name : " + name);
    return true;
  }

} // END QueryController
