/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.storage.impl;

import anthill.*;
import anthill.storage.*;
import anthill.factory.*;

import java.util.*;

/**
 *  Implementation of an LRU based query storage.  This is a wrapper class
 *  for storing resources based on using a query to access the resources.
 *  It inherits all methods from the <CODE>LRUKeyStorage</CODE>,
 *  but adds a method to retrieve resources based on a query.
 *
 *  @author Hein Meling
 *  @version $Revision$
 */
public class LRUQueryStorage
extends LRUKeyStorage
implements QueryStorage
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Private Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** The query controller provided by the implementing class. */
  private QueryController queryCtrl;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Contructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  public LRUQueryStorage(Factory factory, String storageName, String controllerName)
  {
    super(factory, storageName);
    queryCtrl = (QueryController) factory.get(controllerName);
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Public methods for LRUQueryStorage
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Return the resource associated with the specified query.
   *
   *  @param query  whose associated resource to retreive.
   *  @return resources found in the storage with which the
   *    specified query matched.
   */
  public Resource[] getResources(Object query)
  {
    ArrayList array = new ArrayList();
    Iterator iterator = storage.iterator();
    while (iterator.hasNext()) {
      Resource resource = (Resource) iterator.next();
      if (queryCtrl.satisfies(resource, query)) {
        array.add(resource);
      }
    }
    Resource[] resources = new Resource[array.size()];
    array.toArray(resources);
    return resources;
  }

} // END LRUQueryStorage

