/*
 * Copyright (c) 1998-2000 The Anthill Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.util;

import java.io.*;

/**
 *  This class 
 *
 *  @author  Alberto Montresor
 *  @version $Revision$
 */
public class Backtrack
implements Serializable
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Initial size of the backtrack array */
  private static final int STARTING_SIZE = 4;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /** Array containing the back track information */
  private int[] backtrack;
  
  /** Number of elements contained in the array; could size < backtrack.length */
  private int size;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  public Backtrack()
  {
    backtrack = new int[STARTING_SIZE];
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Resizes the backtrack structure by adding the space for a new element.
   */
  public void push()
  {
    size++;
    if (size >= backtrack.length) {
      int[] newbacktrack = new int[backtrack.length*2];
      for (int i=size-2; i >= 0; i--)
        newbacktrack[i] = backtrack[i];
      backtrack = newbacktrack;
    }
  }
  
  /**
   *  Writes the value <CODE>i</CODE> in the last position of the
   *  backtrack data structure.
   */
  public void set(int i)
  {
    backtrack[size] = i;
  }
  
  /**
   *  Writes the value <CODE>i</CODE> in the last position of the
   *  backtrack data structure.
   */
  public int get()
  {
    return backtrack[size];
  }

  /**
   *  
   */
  public void pop()
  {
    if (size > 0)
      size--;
    else {
      System.out.println("Maybe....");
      throw new IllegalStateException("Cannot perform a pop() from an empty backtrack object");
    }
  }
      
  /**
   *  Return the number of elements stored in this backtrack data structure.
   */
  public int size()
  {
    return size;
  }
  
} // END Backtrack

