/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.util;

import java.io.*;

/**
 *  Interface <CODE>Clearable</CODE> is implemented by those objects whose
 *  content may be restored to its initial state. On these 
 *  objects, method <CODE>clear()</CODE> performs the restoration. The aim
 *  of implementing this interface is to avoid the cost of
 *  instantiation of new objects.
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public interface Clearable
{
  
  /**
   *  Restores the object to its initial state.
   */
  public void clear();
  
}

