/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.util;

import anthill.*;

import java.util.*;


/**
 *  This class implements a HashList, which is a combination of a HashMap
 *  and a doubly linked list. The linked listed is always in sorted order
 *  according to the least recently used (LRU) scheme.
 *
 *  @author Hein Meling
 *  @version $Revision$
 */
public class HashList
extends MapList
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Instantiate a new HashList object by setting the maximum number of
   *  composite <CODE>Pair</CODE> objects which may be contained in it.
   *
   *  @param maxsize  maximum number of pair objects which may
   *    be contained in this HashList. If zero, there is no upper
   *    limit to the the size.
   *  @param maxtime  maximum number
   */
  public HashList(int maxsize, int maxtime)
  {
    super(maxsize, maxtime);
    map = (Map) new HashMap(maxsize);
  }

  /**
   *  Instantiate a new HashList object by setting the maximum number of
   *  key, value pairs which may be contained in it.
   *
   *  @param maxsize  Maximum number of objects which may be contained in
   *    this HashList. If zero, there is no upper limit to the the size.
   */
  public HashList(int maxsize)
  {
    super(maxsize);
    map = (Map) new HashMap(maxsize);
  }

} // END HashList

