/*
 * Copyright (c) 1998-2000 The Anthill Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.util;

/**
 *  This class contains the number of instance objects of
 *  a particular class as computed by <CODE>Analyzer</CODE>.
 *
 *  @author  Alberto Montresor
 *  @version $Revision$
 */
public final class InstanceCount
{
  
  /** The class */
  private Class clazz;
  
  /** The counter */
  private int count;
  
  /** 
   *  This constructor counts one instance to the specified
   *  class.
   */
  InstanceCount(Class clazz)
  {
    this.clazz = clazz;
    this.count = 1;
  }
  
  /**
   *  Increments the counter of this object
   */
  void inc()
  {
    count++;
  }
  
  /**
   *  Return the class contained in this object 
   */
  public Class getType()
  {
    return clazz;
  }
  
  /**
   *  Return the counter contained in this object 
   */
  public int getCounter()
  {
    return count;
  }
  
} // END InstanceCount

