/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package freenetant;

import anthill.*;
import anthill.factory.*;
import anthill.util.*;

/**
 *  @author Andrea Piergallini
 *  @author Luca Vagnozzi
 *  @version $Revision$
 */
public class FreenetAntFactory
implements AntFactory
{

  ////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////
  /** 
   * String name of the parameter used to determine the copy probability
   * used by these ants.
   */
  public static final String COPY_PROB = "copyProb";
  public static final String FAKE_PROB = "fakeProb";


  ////////////////////////////////////////////////////////////////////////////
  // Initialization fields
  ////////////////////////////////////////////////////////////////////////////
  
  /* Copy Probability for each Ant */
  private int copyProb;

  /* Fake Probability for each Ant */
  private int fakeProb;

  /* Factory used to instantiate objects */
  private Factory factory;
  
  
  ////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////

  /**
   * Constructor for the freenet ant. Set the factory and the copy
   * probability.
   */
  public FreenetAntFactory(Factory factory, int copyProb, int fakeProb) {
    this.factory = factory;
    this.copyProb = copyProb;
    this.fakeProb = fakeProb;
    clear(); 
  }
  
  /**
   * Restores the object to its initial state.
   */
  public void clear() {
    try {
      this.copyProb = factory.intValue(COPY_PROB);
    } catch (Exception e) {
      e.printStackTrace();
   }

    try {
      this.fakeProb = factory.intValue(FAKE_PROB);
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
  
  ////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////

  /**
   * Returns a freenet ant for a query. This ant will take care of
   * the research of a query string (hash value). 
   */
  public Ant[] getAnts(RequestId rid, Object request, NestId requestor)
  {
    Ant[] ants = new Ant[1];
    ants[0] = new FreenetAnt(rid, (String) request, copyProb, fakeProb, requestor);
    return ants;
  }
  
} // END FreenetAntFactory


