// ShiftOp
// Copyright (c) 1998 Matthew Faupel
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License version 2 as
// published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
// 
// This Java class is inspired in part by the GAGS C++ library which I
// presume to be copyright J. J. Merelo <jmerelo@kal-el.ugr.es>.

package gajit;

import gajit.util.RandomInt;

/**
 * A class that represents a unary genetic operator that randomly adds or
 * subtracts one from the value of a random gene in a chromosome and does
 * the opposite to the next gene in the chromosome.
 *
 * @author Matthew.Faupel@ansa.co.uk
 * @version 0.1
 */
public class ShiftOp extends GenOp
{
    /**
     * Length of each gene
     */
    protected int len;

    public ShiftOp( int geneLength )
    {
        super( false );
        len = geneLength;
    }

    public Chrom apply( Chrom chrom1 )
    {
        return applyAt( RandomInt.next(
            compNumGenes( chrom1, len ) - 1 ) * len, chrom1 );
    }

    public Chrom applyAt( int index, Chrom chrom1 )
    {
        int numGenes = compNumGenes( chrom1, len );

        // Needs at least two genes

        if (numGenes > 1)
        {
            index -= index % len;

            if (index <= chrom1.size() - (len * 2))
            {
                long value1 = chrom1.getLongAt( index, len );
                long value2 = chrom1.getLongAt( index + len, len );

                if (Math.random() < 0.5)
                {
                    --value1;
                    ++value2;
                }
                else
                {
                    ++value2;
                    --value1;
                }

                chrom1.setLongAt( index, len, value1 );
                chrom1.setLongAt( index + len, len, value2 );
            }
        }

        return chrom1;
    }

    public Chrom applyAt( int index, Chrom chrom1, Chrom chrom2 )
    {
        return applyAt( index, chrom1 );
    }
}
