/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package gnutant;

import java.io.*;
import java.net.*;
import java.util.*;

/**
 *  A request object for inserting a document reference into a
 *  peer network.
 *
 *  @author Hein Meling
 *  @version $Revision$
 */
class InsantRequest
{
  /** A url reference to the document being inserted. */
  UrlResource urlResource;

  /** A keyword string associated with this document. */
  String keywords;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Creates an InsantRequest object for the specified URL.
   *  This constructor computes keywords based on the filename
   *  supplied with the URL.
   */
  InsantRequest(URL url, String keywords)
    throws IOException
  {
    this.keywords = keywords;
    urlResource = new UrlResource(url);
  }

  /**
   *  Creates an InsantRequest object for the specified URL.
   *  This constructor computes keywords based on the filename
   *  supplied with the URL.
   *
   *  SIMULATION VERSION.
   */
  InsantRequest(String urlString, String keywords)
  {
    this.keywords = keywords;
    urlResource = new UrlResource(urlString);
  }

} // END InsantRequest


