/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package gnutant;

import anthill.*;
import anthill.util.*;
import java.io.*;

/**
 *
 *  @author Hein Meling
 *  @version $Revision$
 */
public class ReplyGnutant
implements Ant, Serializable
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** The identifier of the request */
  private RequestId rid;

  /** Resource to be returned to the requestor nest */
  private Resource[] resources;

  /** Identifier of the requestor nest */
  private NestId requestor;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Default constructor for externalization
   */
  public ReplyGnutant()
  {
  }

  /**
   *  Initializes a new ReplyGnutant with the set of resources to be returned,
   *  the request identifier and the identifier of the requestor nest.
   */
  public ReplyGnutant(RequestId rid, Resource[] resources, NestId requestor)
  {
    this.rid = rid;
    this.resources = resources;
    this.requestor = requestor;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  // Documentation inherited by interface
  public String getSpecies()
  {
    return "Gnutant";
  }

  public void init(AntView view)
  {
  }

  /**
   *  This method encapsulate the computation performed by the ant.
   *
   *  @param view reference to the AntView object which
   *    constitutes the controlled environment of the ant
   */
  public void run(AntView view)
  {
    if (!requestor.equals(view.getNestId())) {
      try {
        view.move(requestor);
      } catch (Exception e) {
        // Do nothing; the requestor is not there
        Log.print(200, "@"); // This should never happen in the simulation!
      }
    } else {
      /* We are in the requestor nest */
      view.returnResources(rid, resources);
    }
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Externalization methods
  ////////////////////////////////////////////////////////////////////////////////////////////

} // END ReplyGnutant
