/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package gnutant;

import anthill.*;
import anthill.util.*;
import java.io.*;

/**
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class ResponseGnutant
implements Ant, Serializable
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** The identifier of the request */
  private RequestId rid;

  /** Resource to be returned to the requestor nest */
  private Resource[] resources;
  
  /** Identifier of the requestor nest */
  private NestId requestor;

  /** 
   *  Ant identifier to be used to obtain information about the requestor
   *  nest
  */
  private AntId responseId;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Initializes a new ResponseGnutant with the set of resources to
   *  be returned, the identifier of the requestor nest and an ant
   *  identifier to be used to obtain return information through nests.
   */
  public ResponseGnutant(RequestId rid, Resource[] resources, NestId requestor, AntId responseId)
  {
    this.rid = rid;
    this.resources = resources;
    this.requestor = requestor;
    this.responseId = responseId;
  }
  
  /**
   *  Default constructor for externalization
   */
  public ResponseGnutant()
  {
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  // Documentation inherited by interface
  public String getSpecies()
  {
    return "Gnutant";
  }

  public void init(AntView view)
  {
  }

  /**
   *  This method encapsulate the computation performed by the
   *  ant. 
   *
   *  @param view reference to the AntView object which
   *    constitutes the controlled environment of the ant
   */
  public void run(AntView view)
  {
    if (requestor != null) {
      /*
       *  In this case, we are storing the identifier of
       *  the original requestor; this happens when the
       *  ant is created
       */
      NestId req = requestor;
      requestor = null;
      try {
        view.move(req);
      } catch (Exception e) {
        // Do nothing; the requestor is not there
      }
    } else {
      /*
       *  We are in the nest selected as requestor when
       *  moving backward. This could be the actual
       *  requestor nest, or some nest in between
       */
      NestId nest = view.getReturnNest(responseId, false);
      if (nest != null) {
        /* We are not in the requestor nest, move back */
        try { view.move(nest); } catch (Exception e) { } 
      } else {
        /* We are in the requestor nest or we lost the trail */
        view.returnResources(rid, resources);
      }
    }
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Externalization methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  
} // END GnutantBack

