/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package gnutant;

import anthill.*;
import anthill.storage.*;
import anthill.util.*;
import java.io.*;
import java.util.*;

/**
 *
 *  @author Alberto Montresor
 *  @version $Revision$
 */
public class TrailGnutant
implements Ant, Serializable
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Resource to be returned to the requestor nest */
  private Resource[] resources;
  
  /** The hash value of the keyword searched by this ant */
  private KeyHash key;
  
  private NestId provider;
  
  /** 
   *  Ant identifier to be used to obtain information about the requestor
   *  nest
   */
  private AntId trailId;

  // private History history;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Initializes a new TrailGnutant with the set of resources to
   *  be returned, the identifier of the requestor nest and an ant
   *  identifier to be used to obtain return information through nests.
   */
  public TrailGnutant(NestId provider, KeyHash key, Resource[] resources, AntId trailId, History history)
  {
    this.provider = provider;
    this.key = key;
    this.resources = resources;
    this.trailId = trailId;
    // this.history = history;
    //System.out.println("Going back with " + resources.length + " resources!");
  }
  
  /**
   *  Default constructor for externalization
   */
  public TrailGnutant()
  {
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  // Documentation inherited by interface
  public String getSpecies()
  {
    return "Gnutant";
  }

  public void init(AntView view)
  {
  }
  
  /**
   *  This method encapsulate the computation performed by the
   *  ant. 
   *
   *  @param view reference to the AntView object which
   *    constitutes the controlled environment of the ant
   */
  public void run(AntView view)
  {
    // history.add("----------------------------------------------------------------------");
    // history.add("ResponseGnutant: current " + view.getNestId() + " TTL " + view.getTTL());
    
    /*
     *  Updates the routing information for the key it is searching.
     */
    GnutantPheromone pher = (GnutantPheromone) view.getPheromone();
    if (pher != null && !view.getNestId().equals(provider)) {
      /* Add the keyhash and the previous nest to the local pheromone table. */
      pher.addKeyhash(key, provider);
      // history.add("Adding (" + key + ", " + provider + ")");
    }
    
    /*
     *  Add resources to the system  
     */
    QueryStorage storage = (QueryStorage) view.getStorage(Storage.URL_STORAGE);
    if (storage == null)
      throw new IllegalStateException("URL Storage not found");
    for (int i=0; i < resources.length; i++) {
      try {
        storage.addResource(resources[i].getKey(), resources[i]);
        // history.add("Adding " + resources[i]);
      } catch (CapacityException e) {
        System.out.println(resources[i]);
        System.out.println("Size: " + resources[i].size());
        System.err.println(e);
      }
    }
    
    /*
     *  The ant moves to the previous nest; if the ant has lost the trail
     *  (nest == null) or it has arrived to the orginating nest
     *  (nest == view.getNestId()), it just commits suicide.
     */
    NestId nest = view.getReturnNest(trailId, false);
    if (nest != null && !nest.equals(view.getNestId())) {
      try { 
        view.move(nest); 
        return;
      } catch (Exception e) { 
        // history.add("Unable to reach nest " + nest);
      } 
    } else {
      if (nest == null) {
        System.out.print("+");
        // history.add("ResponseGnutant has lost the trail");
      } else {
        // history.add("ResponseGnutant has reached originating nest");
      }
    }
    //history.print();
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Externalization methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  
} // END TrailBack

